@@ -8,24 +8,30 @@ IGNORE_SOURCE = ["/"]
 class AuthMiddleware(MiddlewareMixin):
     def process_request(self, request):
         path = request.path
+        results = Results()
         if "login" not in path and path not in IGNORE_SOURCE:
-            account = request.session.get("account", None)
-            results = Results()
-            if not account:
-                results.describe = "no permission!!!"
-                results.code = FORBID_CODE
-                return RESTResponse(results)
-            authorization = self.permissions(request, account)
+            token = request.GET.get('token')
+            if token:
+                tenant = Tenant.objects.filter(token=token).first()
+                authorization = self.permissions(request, tenant=tenant)
+            else:
+                account = request.session.get("account", None)
+                if not account:
+                    results.describe = "no permission!!!"
+                    results.code = FORBID_CODE
+                    return RESTResponse(results)
+                authorization = self.permissions(request, account=account)
             if not authorization:
                 results.describe = "no permission!!!"
                 results.code = FORBID_CODE
                 return RESTResponse(results)
 
-    def permissions(self, request, account):
+    def permissions(self, request, account=None, tenant=None):
 
         method = request.method
         path = request.path
-        tenant = Tenant.objects.filter(account=account).first()
+        if not tenant:
+            tenant = Tenant.objects.filter(account=account).first()
         if tenant:
             if tenant.account == "admin":
                 return True
